@@ -4,9 +4,12 @@ from iota.crypto.addresses import AddressGenerator
 import pathlib,logging,argparse,random
 LETTERS="ABCDEFGHIJKLMNOPQRSTUVWXYZ9"
 class Escrow:
-    def __init__(self,node='https://nodes.thetangle.org:443'):
-        #Get Seet
-        self.seed = self.getSeed()
+    def __init__(self,node='https://nodes.thetangle.org:443',seed=None):
+        #Get Seed
+        if seed is None:
+            self.seed = self.getSeed()
+        else:
+            self.seed = seed
 
         #Setup API
         self.api = Iota(node,self.seed)
@@ -55,6 +58,8 @@ class Escrow:
     def startCli(self,collateral,fee=0,delay=120,deposit=None):
         #Create holding address
         self.createEscrow()
+        self.fee=fee
+        self.collateral=collateral
         #Wait for a deposit address to be entered
         if self.requestDeposit(collateral,deposit,delay):
             while not self.checkCondition():
@@ -66,7 +71,7 @@ class Escrow:
         #For CLI prompt a deposit address
         if deposit is None:
             self.deposit = input("What is the deposit address: ")
-        print(f"You have {duration/60:.1f} min to deposit {collateral} MIOTA to {self.holdingAddress}")
+        print(f"You have {duration/60:.1f} min to deposit {collateral} IOTA to {self.holdingAddress}")
 
         #Wait for escrow to recive collateral funds.
         count = 0
@@ -155,7 +160,7 @@ class Escrow:
 
 def createEscrow(args):
     escrow = Escrow(node=args.node)
-    escrow.startCli(50,7)
+    escrow.startCli(args.collateral,args.fee)
     
 def main():
     parser = argparse.ArgumentParser(description='Basic escrow using IOTA.')
